---
title: <span class="badge object-type-scalar"></span> BitsIEC
---
# <span class="badge object-type-scalar"></span> BitsIEC

Data: bits(IEC)

## Definition

```python
# Data: bits(IEC)
BitsIEC: typing.Literal["bits"] = "bits"
```
